==> libuta-0.3.40.tgz: include/uta/sample.h <==
/*
  libuta - a C++ widget library based on SDL (Simple Direct Layer)
  Copyright (C) 1999  Karsten Laux <klaux@student.uni-kl.de>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.
  
  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA  02111-1307, SA.
*/

// writtten May 1999



#ifndef _SAMPLE_H
#define _SAMPLE_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "sound.h"

#include <string>

namespace uta {

///
class Sample : public Sound
{

public:

  ///
  Sample();
  ///
  Sample(const Sample&);
  ///
  Sample(const string&);
  ///
  virtual ~Sample();


  /// set volume (0..100)
  virtual int setVolume(int vol);  
  ///
  virtual bool load(const string&);
  ///
  virtual bool play(int loops = 0) const;
  ///
  virtual void stop() const;
  ///
  virtual bool playing() const;

 protected:

#ifdef HAVE_MIXER
  ///
  Mix_Chunk* data_;
#endif
  mutable int channel_;

};

}

#endif

==> libuta-0.4.4p3.tgz: include/uta/sample.h <==
/*
  libuta - a C++ widget library based on SDL (Simple Direct Layer)
  Copyright (C) 1999-2002  Karsten Laux <klaux@student.uni-kl.de>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA  02111-1307, SA.
*/

// writtten May 1999



#ifndef _SAMPLE_H
#define _SAMPLE_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "sound.h"

#include <string>

namespace uta {

///
class Sample : public Sound
{

public:

  ///
  Sample();
  ///
  Sample(const Sample&);
  ///
  Sample(const std::string&);
  ///
  virtual ~Sample();


  /// set volume (0..100)
  virtual int setVolume(int vol);  
  ///
  virtual bool load(const std::string&);
  ///
  virtual bool play(int loops = 0) const;
  ///
  virtual void stop() const;
  ///
  virtual bool playing() const;

 protected:

#ifdef HAVE_MIXER
  ///
  Mix_Chunk* data_;
#endif
  mutable int channel_;

};

}

#endif
